
import { useState } from 'react';

import { LibraryTable } from './components/LibraryTable';
import { LibraryModal } from './components/LibraryModal';
import { SearchBar } from './components/SearchBar';
import { Library } from './components/types';
import { api } from '@nice/client';
import { message } from 'antd';

export const LibraryPage = () => {
  const [modalOpen, setModalOpen] = useState(false);
  const [editingLibrary, setEditingLibrary] = useState<Library | undefined>();
  const [searchText, setSearchText] = useState('');

  // 查询数据
  const { data, isLoading, refetch, isError, error } = api.library.findMany.useQuery({
    where: {
      deletedAt: null,
      OR: searchText.trim()  ? [
        { name: { contains: searchText } },
        { address: { contains: searchText } },
        { description: { contains: searchText } },
      ] : undefined
    },
    include: {
      
    },
  });

  if (isError && error) {
    message.error('获取数据失败：' + error.message);
  }

  // 创建数据
  const createMutation = api.library.create.useMutation({
    onSuccess: () => {
      message.success('创建成功');
      setModalOpen(false);
      refetch();
    },
    onError: (error) => {
      message.error('创建失败：' + error.message);
    }
  });

  // 更新数据
  const updateMutation = api.library.update.useMutation({
    onSuccess: () => {
      message.success('更新成功');
      setModalOpen(false);
      refetch();
    },
    onError: (error) => {
      message.error('更新失败：' + error.message);
    }
  });

  // 删除数据
  const deleteMutation = api.library.softDeleteByIds.useMutation({
    onSuccess: () => {
      message.success('删除成功');
      refetch();
    },
    onError: (error) => {
      message.error('删除失败：' + error.message);
    }
  });

  // 处理搜索
  const handleSearch = () => {
    refetch();
  };

  // 处理添加
  const handleAdd = () => {
    setEditingLibrary(undefined);
    setModalOpen(true);
  };

    // 处理模态框取消，并确保清空 editingLibrary 状态
    const handleCancelModal = () => {
      setModalOpen(false);
      setEditingLibrary(undefined); // 关键：在关闭模态框时，清除编辑对象
    };
  

  // 处理表单提交
  const handleModalOk = (values: any) => {
    if (editingLibrary) {
      updateMutation.mutate({
        where: { id: editingLibrary.id },
        data: {
          name: values.name,
          address: values.address,
          description: values.description,
          
        }
      });
    } else {
      createMutation.mutate({
        
        name: values.name,
        address: values.address,
        description: values.description,
        
      });
    }
  };

  return (
    <div className="p-6">
      <SearchBar
        searchText={searchText}
        onSearchTextChange={setSearchText}
        onSearch={handleSearch}
        onAdd={handleAdd}
        onImportSuccess={refetch}
        data={data || []}
      />

      <LibraryTable
        data={data || []}
        loading={isLoading}
        onEdit={(library) => {
          setEditingLibrary(library);
          setModalOpen(true);
        }}
        onDelete={(ids) => deleteMutation.mutate({ ids })}
      />

      <LibraryModal
        open={modalOpen}
        editingLibrary={editingLibrary}
        libraryList={data || []}
        loading={createMutation.isLoading || updateMutation.isLoading}
        onOk={handleModalOk}
        onCancel={handleCancelModal}
      />
    </div>
  );
};

export default LibraryPage;