import { Modal, Form, Input, Select } from 'antd';
import { Library } from './types';
import React ,{useEffect}from 'react';

interface LibraryModalProps {
  open: boolean;
  loading?: boolean;
  editingLibrary?: Library;
  libraryList?: Library[];
  onOk: (values: any) => void;
  onCancel: () => void;
}

export const LibraryModal: React.FC<LibraryModalProps> = ({
  open,
  loading,
  editingLibrary,
  libraryList,
  onOk,
  onCancel,
}) => {
  const [form] = Form.useForm();
    

  // 核心逻辑：当模态框的打开状态或编辑对象改变时，更新表单
  useEffect(() => {
    if (open) {
      // 当模态框打开时
      if (editingLibrary) {
        // 如果有编辑中的图书馆（编辑模式），则填充表单
        form.setFieldsValue(editingLibrary);
      } else {
        // 如果没有编辑中的图书馆（新增模式），则清空表单
        form.resetFields();
      }
    } else {
      // 当模态框关闭时，也清空表单，为下一次打开（特别是新增）做准备
      form.resetFields();
    }
  }, [open, editingLibrary, form]); // 依赖项：模态框的打开状态、编辑对象和表单实例

  return (
    <Modal
      title={editingLibrary ? '编辑图书馆' : '新增图书馆'}
      open={open}
      onOk={() => form.submit()}
      onCancel={onCancel}
      confirmLoading={loading}
    >
      <Form
        form={form}
        layout="vertical"
        initialValues={editingLibrary}
        onFinish={(values) => {
          // 确保数据格式正确
          const formData = {
            name: values.name,
            address: values.address,
            description: values.description,
          
          };
          onOk(formData);
        }}
      >
        <Form.Item
          name="name"
          label="图书馆名称"
          rules={[{ required: true, message: '请输入图书馆名称' }]}
        >
          <Input />
          </Form.Item>

          <Form.Item
          name="address"
          label="地址"
          rules={[{ required: true, message: '请输入图书馆地址' }]}
        >
          <Input />
        </Form.Item>

        <Form.Item
          name="description"
          label="描述"
          rules={[{ required: true, message: '请输入俱乐部描述' }]}
        >
          <Input.TextArea />
        </Form.Item>

        {/* <Form.Item
          name="parentId"
          label="上级俱乐部"
        >
          <Select
            allowClear
            disabled={editingLibrary?.id ? libraryList?.some(c => c.id === editingLibrary.id) : false}
          >
            {libraryList?.filter(library => library.id !== editingLibrary?.id).map(library => (
              <Select.Option key={library.id} value={library.id}>
                {library.name}
              </Select.Option>
            ))}
          </Select>
        </Form.Item> */}
      </Form>
    </Modal>
  );
};